from distutils.core import setup

setup(
    name='qiletianTest',
    version='1.0',
    description='这是一个测试',
    author = 'qiletian',
    author_email='1452239845@qq.com',
    py_modules=['qiletianTest.demo1','qiletianTest.demo2'],
)
